@@ -156,6 +156,9 @@ extern void pcbit_setup(char *str, int *ints);
 #ifdef CONFIG_RISCOM8
 extern void riscom8_setup(char *str, int *ints);
 #endif
+#ifdef CONFIG_BAYCOM
+extern void baycom_setup(char *str, int *ints);
+#endif
 
 
 #if defined(CONFIG_SYSVIPC) || defined(CONFIG_KERNELD)
@@ -391,6 +394,9 @@ struct {
 #endif
 #ifdef CONFIG_RISCOM8
 	{ "riscom8=", riscom8_setup },
+#endif
+#ifdef CONFIG_BAYCOM
+	{ "baycom=", baycom_setup },
 #endif
 	{ 0, 0 }
 };
